AudioOutputOptions class

An object that configures what device(s) may be offered in the user prompt.

Constructors

AudioOutputOptions({String deviceId = ''})

Properties

deviceId → String
A string representing the id of the (only) device to display in the prompt (with default value: "").
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited