CameraUtils class

Constructors

CameraUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setExposureMode(MediaStreamTrack videoTrack, CameraExposureMode exposureMode) → Future<void>
setExposurePoint(MediaStreamTrack videoTrack, Point<double>? point) → Future<void>
setFocusMode(MediaStreamTrack videoTrack, CameraFocusMode focusMode) → Future<void>
Set the exposure point for the camera, focusMode can be: 'auto', 'locked'
setFocusPoint(MediaStreamTrack videoTrack, Point<double>? point) → Future<void>
setZoom(MediaStreamTrack videoTrack, double zoomLevel) → Future<void>