DesktopCapturerSource class abstract

Constructors

DesktopCapturerSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The identifier of a window or screen that can be used as a chromeMediaSourceId constraint when calling
no setter
name → String
A screen source will be named either Entire Screen or Screen index, while the name of a window source will match the window title.
no setter
onNameChanged → StreamController<String>
no setter
onThumbnailChanged → StreamController<Uint8List>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → Uint8List?
A thumbnail image of the source. jpeg encoded.
no setter
thumbnailSize → ThumbnailSize
specified in the options passed to desktopCapturer.getSources. The actual size depends on the scale of the screen or window.
no setter
type → SourceType
The type of the source.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited