toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buffer = StringBuffer('E2eeEvent($name');
  if (userId.isNotEmpty) buffer.write(', userId: $userId');
  if (trackType != null) buffer.write(', trackType: $trackType');
  if (keyIndex != null) buffer.write(', keyIndex: $keyIndex');
  if (version != null) buffer.write(', version: $version');
  if (reason != null) buffer.write(', reason: $reason');
  if (keyState != null) buffer.write(', keyState: $keyState');
  if (encode != null) buffer.write(', encode: $encode');
  if (decode != null) buffer.write(', decode: $decode');
  return (buffer..write(')')).toString();
}