E2eeEventType enum

Kinds of e2ee.* event emitted by the native manager.

Inheritance
Available extensions

Values

decryptionFailed → const E2eeEventType
const E2eeEventType(0, 'e2ee.decryption_failed')
decryptionResumed → const E2eeEventType
const E2eeEventType(1, 'e2ee.decryption_resumed')
decryptionStalled → const E2eeEventType
const E2eeEventType(2, 'e2ee.decryption_stalled')
encryptionFailed → const E2eeEventType
const E2eeEventType(3, 'e2ee.encryption_failed')
missingKey → const E2eeEventType
const E2eeEventType(4, 'e2ee.missing_key')
unencryptedFrame → const E2eeEventType
const E2eeEventType(5, 'e2ee.unencrypted_frame')
unsupportedVersion → const E2eeEventType
const E2eeEventType(6, 'e2ee.unsupported_version')
keyState → const E2eeEventType
const E2eeEventType(7, 'e2ee.key_state')
perfReport → const E2eeEventType
const E2eeEventType(8, 'e2ee.perf_report')

Properties

eventName String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int? value) E2eeEventType?
Resolves a native ordinal, or null when value is out of range.

Constants

values → const List<E2eeEventType>
A constant List of the values in this enum, in order of their declaration.