E2eeKeyState class

Payload of an e2ee.key_state event.

Constructors

E2eeKeyState({required List<E2eeUserKey> perUserKeys, required List<E2eeSharedKey> sharedKeys})
const
E2eeKeyState.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
perUserKeys → List<E2eeUserKey>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedKeys → List<E2eeSharedKey>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited