E2eeSharedKey class

A key registered for every participant at a given index.

Constructors

E2eeSharedKey({required int keyIndex, required String fingerprint, required bool isActive})
const
E2eeSharedKey.fromMap(Map map)
factory

Properties

fingerprint String
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether this index is the one used to encrypt outgoing frames.
final
keyIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited