E2eeTrackPerf class

One row of an e2ee.perf_report event.

Constructors

E2eeTrackPerf({required String userId, required E2eeTrackType? trackType, required String? codec, required double fps, required double maxCryptoMs})
const
E2eeTrackPerf.fromMap(Map map)
factory

Properties

codec String?
Set on encode samples only.
final
fps double
final
hashCode int
The hash code for this object.
no setterinherited
maxCryptoMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackType E2eeTrackType?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited