E2eeUserKey class

A key registered for a specific remote user.

Constructors

E2eeUserKey({required String userId, required int keyIndex, required String fingerprint})
const
E2eeUserKey.fromMap(Map map)
factory

Properties

fingerprint → String
final
hashCode → int
The hash code for this object.
no setterinherited
keyIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited