FrameCryptor class abstract

Frame encryption/decryption.

Constructors

FrameCryptor()

Properties

enabled → Future<bool>
Get the enabled state for the sender or receiver.
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyIndex → Future<int>
Get the key index for the sender or receiver.
no setter
onFrameCryptorStateChanged ↔ dynamic Function(String participantId, FrameCryptorState state)?
getter/setter pair
participantId → String
The unique identifier of the frame cryptor.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Dispose the frame cryptor.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnabled(bool enabled) → Future<bool>
Enable/Disable frame crypto for the sender or receiver.
setKeyIndex(int index) → Future<bool>
Set the key index for the sender or receiver. If the key index is not set, the key index will be set to 0.
toString() → String
A string representation of this object.
inherited
updateCodec(String codec) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited