Helper class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
clearAndroidCommunicationDevice ()
→ Future <void >
After Android app finishes a session, on audio focus loss, clear the active communication device.
enableIOSMultitaskingCameraAccess (bool enable )
→ Future <bool >
Enable or disable iOS multitasking camera access (iOS only).
ensureiOSAudioSession ()
→ Future <void >
Ensure audio session
for iOS only
enumerateDevices (String type )
→ Future <List <MediaDeviceInfo > >
isiOSStereoPlayoutEnabled ()
→ Future <bool >
Returns whether stereo playout is currently enabled (iOS only).
openCamera (Map <String , dynamic > mediaConstraints )
→ Future <MediaStream >
To select a a specific camera, you need to set constraints
eg.
var constraints = {
'audio': true,
'video': {
'deviceId': Helper.cameras0.deviceId,
}
};
pauseAudioPlayout ()
→ Future <void >
Pause remote audio playout (iOS/macOS via ADM, Android by muting remote tracks)
refreshiOSStereoPlayoutState ()
→ Future <void >
Refreshes the stereo playout state on the ADM (iOS only).
regainAndroidAudioFocus ()
→ Future <void >
Force Android to re-request audio focus after a loss.
requestCapturePermission ()
→ Future <bool >
Request capture permission for Android
resumeAudioPlayout ()
→ Future <void >
Resume remote audio playout after a pause (iOS/macOS WebRTC ADM, Android track volume restore)
selectAudioInput (String deviceId )
→ Future <void >
Set audio input device for Flutter native
Note: The usual practice in flutter web is to use deviceId as the
getUserMedia parameter to get a new audio track and replace it with the
audio track in the original rtpsender.
selectAudioOutput (String deviceId )
→ Future <void >
Used to select a specific audio output device.
setAndroidAudioConfiguration (AndroidAudioConfiguration androidAudioConfiguration )
→ Future <void >
Set the audio configuration to for Android.
Must be set before initiating a WebRTC session and cannot be changed
mid session.
setAppleAudioConfiguration (AppleAudioConfiguration appleAudioConfiguration )
→ Future <void >
Set the audio configuration for iOS
setAppleAudioIOMode (AppleAudioIOMode mode , {bool preferSpeakerOutput = false })
→ Future <void >
Set the audio configuration for iOS
setExposureMode (MediaStreamTrack videoTrack , CameraExposureMode exposureMode )
→ Future <void >
setExposurePoint (MediaStreamTrack videoTrack , Point <double > ? point )
→ Future <void >
setFocusMode (MediaStreamTrack videoTrack , CameraFocusMode focusMode )
→ Future <void >
setFocusPoint (MediaStreamTrack videoTrack , Point <double > ? point )
→ Future <void >
setiOSStereoPlayoutPreferred (bool preferred )
→ Future <void >
Set whether stereo playout is preferred (iOS only).
setLogger (Logger logger , [String severity = 'none' ])
→ void
Set Logger object for webrtc;
setMicrophoneMute (bool mute , MediaStreamTrack track )
→ Future <void >
Set the microphone mute/unmute for Flutter native
setSpeakerphoneOn (bool enable )
→ Future <void >
Enable or disable speakerphone
for iOS/Android only
setSpeakerphoneOnButPreferBluetooth ()
→ Future <void >
Enable speakerphone, but use bluetooth if audio output device available
for iOS/Android only
setVolume (double volume , MediaStreamTrack track )
→ Future <void >
Set the volume for Flutter native
setZoom (MediaStreamTrack videoTrack , double zoomLevel )
→ Future <void >
switchCamera (MediaStreamTrack track , [String ? deviceId , MediaStream ? stream ])
→ Future <bool >
For web implementation, make sure to pass the target deviceId
triggeriOSAudioRouteSelectionUI ()
→ Future <void >
Trigger the iOS audio route selection UI (iOS only).
stream_webrtc_flutter 2.2.5