KeyProvider class abstract

Shared secret key for frame encryption.

Constructors

KeyProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the key provider.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Dispose the key manager.
exportKey({required String participantId, required int index}) → Future<Uint8List>
Export the key at the given index.
exportSharedKey({int index = 0}) → Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ratchetKey({required String participantId, required int index}) → Future<Uint8List>
ratchet the key at the given index.
ratchetSharedKey({int index = 0}) → Future<Uint8List>
setKey({required String participantId, required int index, required Uint8List key}) → Future<bool>
Set the raw key at the given index.
setSharedKey({required Uint8List key, int index = 0}) → Future<void>
setSifTrailer({required Uint8List trailer}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited