MediaRecorder class

Constructors

MediaRecorder({String? albumName})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start(String path, {MediaStreamTrack? videoTrack, RecorderAudioChannel? audioChannel, int rotationDegrees = 0}) → Future<void>
Starts recording to file at path. Optionally, on Android choose audioChannel to record. On web platform use startWeb instead.
startWeb(MediaStream stream, {dynamic onDataChunk(dynamic blob, bool isLastOne)?, String? mimeType, int timeSlice = 1000}) → void
Only for Flutter Web
stop() → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited