RTCDataChannel class abstract

Constructors

RTCDataChannel()

Properties

bufferedAmount → int?
no setter
bufferedAmountLowThreshold ↔ int?
Set threshold to trigger onBufferedAmountLow callback
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int?
Get channel id
no setter
label → String?
Get channel label
no setter
messageStream ↔ Stream<RTCDataChannelMessage>
Stream of incoming messages. Emits the message. Closes when the RTCDataChannel is closed.
getter/setter pair
onBufferedAmountChange ↔ dynamic Function(int currentAmount, int changedAmount)?
getter/setter pair
onBufferedAmountLow ↔ dynamic Function(int currentAmount)?
getter/setter pair
onDataChannelState ↔ dynamic Function(RTCDataChannelState state)?
getter/setter pair
onMessage ↔ dynamic Function(RTCDataChannelMessage data)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → RTCDataChannelState?
Get current state.
no setter
stateChangeStream ↔ Stream<RTCDataChannelState>
Stream of state change events. Emits the new state on change. Closes when the RTCDataChannel is closed.
getter/setter pair

Methods

close() → Future<void>
getBufferedAmount() → Future<int>
Get the buffered amount from native DC.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(RTCDataChannelMessage message) → Future<void>
Send a message to this datachannel. To send a text message, use the default constructor to instantiate a text RTCDataChannelMessage for the message parameter. To send a binary message, pass a binary RTCDataChannelMessage constructed with RTCDataChannelMessage.fromBinary
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited