RTCFactory class abstract

Implementers

Constructors

RTCFactory()

Properties

frameCryptorFactory → FrameCryptorFactory
no setter
hashCode → int
The hash code for this object.
no setterinherited
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createLocalMediaStream(String label) → Future<MediaStream>
createPeerConnection(Map<String, dynamic> configuration, [Map<String, dynamic> constraints]) → Future<RTCPeerConnection>
getRtpReceiverCapabilities(String kind) → Future<RTCRtpCapabilities>
getRtpSenderCapabilities(String kind) → Future<RTCRtpCapabilities>
mediaRecorder() → MediaRecorder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
videoRenderer() → VideoRenderer

Operators

operator ==(Object other) → bool
The equality operator.
inherited