RTCFactoryNative class

Inheritance

Properties

frameCryptorFactory → FrameCryptorFactory
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createLocalMediaStream(String label) → Future<MediaStream>
override
createPeerConnection(Map<String, dynamic> configuration, [Map<String, dynamic> constraints = const {}]) → Future<RTCPeerConnection>
override
getRtpReceiverCapabilities(String kind) → Future<RTCRtpCapabilities>
override
getRtpSenderCapabilities(String kind) → Future<RTCRtpCapabilities>
override
handleCallInterruptionCallbacks(void onInterruptionStart()?, void onInterruptionEnd()?, {AndroidInterruptionSource androidInterruptionSource = AndroidInterruptionSource.audioFocusAndTelephony, AndroidAudioAttributesUsageType? androidAudioAttributesUsageType, AndroidAudioAttributesContentType? androidAudioAttributesContentType}) → Future<void>
mediaRecorder() → MediaRecorder
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVideoEffects(String trackId, List<String> names) → Future<void>
toString() → String
A string representation of this object.
inherited
videoRenderer() → VideoRenderer
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → RTCFactory
final