RTCIceCandidate class

Constructors

RTCIceCandidate(String? candidate, String? sdpMid, int? sdpMLineIndex)

Properties

candidate → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdpMid → String?
final
sdpMLineIndex → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited