RTCRTCPParameters class

Constructors

RTCRTCPParameters(String? cname, bool reducedSize)
RTCRTCPParameters.fromMap(Map map)
factory

Properties

cname ↔ String?
The Canonical Name used by RTCP
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reducedSize ↔ bool
Whether reduced size RTCP is configured or compound RTCP
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited