RTCRTPCodec class

Constructors

RTCRTPCodec({int? payloadType, String? name, String? kind, int? clockRate, int? numChannels, Map? parameters})
RTCRTPCodec.fromMap(Map map)
factory

Properties

clockRate ↔ int?
Clock rate in Hertz.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The media type of this codec. Equivalent to MIME top-level type.
getter/setter pair
name ↔ String?
Name used to identify the codec. Equivalent to MIME subtype.
getter/setter pair
numChannels ↔ int?
The number of audio channels used. Set to null for video codecs.
getter/setter pair
parameters ↔ Map?
The "format specific parameters" field from the "a=fmtp" line in the SDP
getter/setter pair
payloadType ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited