RTCRtpCapabilities class

Constructors

RTCRtpCapabilities({List<RTCRtpCodecCapability>? codecs, List<RTCRtpHeaderExtensionCapability>? headerExtensions, List<String>? fecMechanisms})
RTCRtpCapabilities.fromMap(Map map)
factory

Properties

codecs ↔ List<RTCRtpCodecCapability>?
getter/setter pair
fecMechanisms ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerExtensions ↔ List<RTCRtpHeaderExtensionCapability>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited