RTCRtpCodecCapability class

Constructors

RTCRtpCodecCapability({num? channels, required num clockRate, required String mimeType, String? sdpFmtpLine})
RTCRtpCodecCapability.fromMap(Map map)
factory

Properties

channels ↔ num?
getter/setter pair
clockRate ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdpFmtpLine ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited