RTCRtpEncoding class

Constructors

RTCRtpEncoding({String? rid, bool active = true, int? maxBitrate, int? maxFramerate, int? minBitrate, int? numTemporalLayers = 1, double? scaleResolutionDownBy = 1.0, int? ssrc, String? scalabilityMode, RTCPriorityType priority = RTCPriorityType.low, RTCPriorityType? networkPriority})
RTCRtpEncoding.fromMap(Map map)
factory

Properties

active ↔ bool
Set to true to cause this encoding to be sent, and false for it not to be sent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxBitrate ↔ int?
If non-null, this represents the Transport Independent Application Specific maximum bandwidth defined in RFC3890. If null, there is no maximum bitrate.
getter/setter pair
maxFramerate ↔ int?
The max framerate in fps for video.
getter/setter pair
minBitrate ↔ int?
The minimum bitrate in bps for video.
getter/setter pair
networkPriority ↔ RTCPriorityType?
Indicates the network priority of this encoding. Used for DSCP marking.
getter/setter pair
numTemporalLayers ↔ int?
The number of temporal layers for video.
getter/setter pair
priority ↔ RTCPriorityType
Indicates the priority of this encoding relative to other encodings. Used to indicate the importance of the RTP stream for bandwidth allocation. Defaults to "low".
getter/setter pair
rid ↔ String?
If non-null, this represents the RID that identifies this encoding layer. RIDs are used to identify layers in simulcast.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalabilityMode ↔ String?
getter/setter pair
scaleResolutionDownBy ↔ double?
If non-null, scale the width and height down by this factor for video. If null, implementation default scaling factor will be used.
getter/setter pair
ssrc ↔ int?
SSRC to be used by this encoding. Can't be changed between getParameters/setParameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited