RTCRtpTransceiver class abstract

Constructors

RTCRtpTransceiver()

Properties

currentDirection → TransceiverDirection
Deprecated methods.
no setter
hashCode → int
The hash code for this object.
no setterinherited
mid → String
no setter
receiver → RTCRtpReceiver
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → RTCRtpSender
no setter
stoped → bool
no setter
transceiverId → String
no setter

Methods

getCurrentDirection() → Future<TransceiverDirection?>
getDirection() → Future<TransceiverDirection>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCodecPreferences(List<RTCRtpCodecCapability> codecs) → Future<void>
setDirection(TransceiverDirection direction) → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited