RTCRtpTransceiverInit class

Constructors

RTCRtpTransceiverInit({TransceiverDirection? direction, List<MediaStream>? streams, List<RTCRtpEncoding>? sendEncodings})

Properties

direction ↔ TransceiverDirection?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendEncodings ↔ List<RTCRtpEncoding>?
getter/setter pair
streams ↔ List<MediaStream>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited