RTCTrackEvent class

Constructors

RTCTrackEvent({RTCRtpReceiver? receiver, required List<MediaStream> streams, required MediaStreamTrack track, RTCRtpTransceiver? transceiver})

Properties

hashCode → int
The hash code for this object.
no setterinherited
receiver → RTCRtpReceiver?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streams → List<MediaStream>
final
track → MediaStreamTrack
final
transceiver → RTCRtpTransceiver?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited