RTCVideoRenderer class

Inheritance
Implemented types
Available extensions

Constructors

RTCVideoRenderer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
muted ↔ bool
getter/setter pairoverride
onFirstFrameRendered ↔ Function?
When the first frame is rendered, notify the user that video started playing.
getter/setter pairoverride
onResize ↔ Function?
When the video size changes, or the native texture changes (angle or size), notify the user to redraw the Widget.
getter/setter pairoverride
renderVideo → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcObject ↔ MediaStream?
getter/setter pairoverride
textureId → int?
no setteroverride
value ↔ RTCVideoValue
The current value stored in this notifier.
getter/setter pairinherited
videoHeight → int
no setteroverride
videoValue → RTCVideoValue

Available on RTCVideoRenderer, provided by the VideoRendererExtension extension

no setter
videoWidth → int
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
audioOutput(String deviceId) → Future<bool>
Return true if the audioOutput have been succesfully changed
override
dispose() → Future<void>
Discards any resources used by the object.
override
errorListener(Object obj) → void
eventListener(dynamic event) → void
initialize() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setSrcObject({MediaStream? stream, String? trackId}) → Future<void>
setVolume(double value) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited