RTCVideoValue class

Constructors

RTCVideoValue({double width = 0.0, double height = 0.0, int rotation = 0, bool renderVideo = false})
const

Properties

aspectRatio → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
renderVideo → bool
final
rotation → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

copyWith({double? width, double? height, int? rotation, bool renderVideo = true}) → RTCVideoValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const RTCVideoValue