VideoRenderer class abstract

Implementers

Constructors

VideoRenderer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
muted ↔ bool
getter/setter pair
onFirstFrameRendered ↔ Function?
When the first frame is rendered, notify the user that video started playing.
getter/setter pair
onResize ↔ Function?
When the video size changes, or the native texture changes (angle or size), notify the user to redraw the Widget.
getter/setter pair
renderVideo → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcObject ↔ MediaStream?
getter/setter pair
textureId → int?
no setter
videoHeight → int
no setter
videoWidth → int
no setter

Methods

audioOutput(String deviceId) → Future<bool>
Return true if the audioOutput have been succesfully changed
dispose() → Future<void>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited