WebRTC class

Constructors

WebRTC()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

initialized ↔ bool
getter/setter pair
platformIsAndroid → bool
no setter
platformIsDesktop → bool
no setter
platformIsIOS → bool
no setter
platformIsLinux → bool
no setter
platformIsMacOS → bool
no setter
platformIsMobile → bool
no setter
platformIsWeb → bool
no setter
platformIsWindows → bool
no setter

Static Methods

initialize({Map<String, dynamic>? options, bool refresh = false}) → Future<void>
Initialize the WebRTC plugin.
invokeMethod<T, P>(String methodName, [dynamic param]) → Future<T?>