IosAudioManagement class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
enableMultitaskingCameraAccess(
bool enable) → Future< bool> - Enable or disable iOS multitasking camera access (iOS only).
-
ensureAudioSession(
) → Future< void> - Ensure audio session (iOS only).
-
isStereoPlayoutEnabled(
) → Future< bool> - Returns whether stereo playout is currently enabled on the ADM (iOS only).
-
refreshStereoPlayoutState(
) → Future< void> - Refreshes the stereo playout state on the ADM (iOS only).
-
setStereoPlayoutPreferred(
bool preferred) → Future< void> - Set whether stereo playout is preferred (iOS only).
-
triggerAudioRouteSelectionUI(
) → Future< void> - Trigger the iOS audio route selection UI (iOS only).